Struct structinator_traits::NamedField
source · pub struct NamedField<I> {
pub name: String,
pub wrapped_value: I,
}Expand description
SpecifyCreatableStruct’s original intended use case was with user-defined structs, and this structure was designed for convenience, allowing the implementor to store both a Stringification of the field’s name,
and the field’s value. Note that it is also the type that the argument passed to create_struct must iterate over.
Fields
name: StringIntended to hold the name of the field wrapped_value should be assigned to
wrapped_value: IIntended to hold the value to be assigned to a given field in the target struct